Flags - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Documentation

# Flags

Thanks to the Tabler flags plug-in, you can create flags to visually represent countries or languages. Flags are often used in forms, as an element of a delivery address, phone number dialling code and many more.

### Installation

This part of Tabler is distributed as plugin. To enable it you should include `tabler-flags.css` or `tabler-flags.min.css` file to your page.

You can also include plugin via CDN:

    <link rel="stylesheet" href="https://unpkg.com/@tabler/core@1.0.0-beta9/dist/css/tabler-flags.min.css">

## Flag

To create a flag, add the `flag` class to a component and choose the country whose flag you want to use. The full list of countries can be found below.

    <span class="flag flag-country-tg me-1"></span>
    <span class="flag flag-country-br me-1"></span>
    <span class="flag flag-country-pt"></span>

## Flag sizes

Using Bootstrap’s typical naming structure, you can create a standard flag, or scale it up or down to different sizes based on what’s needed.

    <span class="flag flag-xl flag-country-pl me-1"></span>
    <span class="flag flag-lg flag-country-pl me-1"></span>
    <span class="flag flag-md flag-country-pl"></span>
    <span class="flag flag-sm flag-country-pl me-1"></span>
    <span class="flag flag-xs flag-country-pl me-1"></span>

## Types

To use the flag of a particular country, add the `flag-country-(country name)` class. For example, to create a flag of Andorra should use the following class: `.flag-country-ad`.

| `ad` | Andorra
| `ae` | United Arab Emirates
| `af` | Afghanistan
| `ag` | Antigua
| `ai` | Anguilla
| `am` | Armenia
| `ao` | Angolan
| `aq` | Antarctica
| `ar` | Argentina
| `as` | American Samoa
| `at` | Austria
| `au` | Australia
| `aw` | Aruba
| `ax` | Aslan Islands
| `az` | Azerbaijan
| `ba` | Bosnian
| `bb` | Barbados
| `be` | Belgium
| `bf` | Burkina Faso
| `bg` | Bulgaria
| `bh` | Bahrain
| `bi` | Burundi
| `bj` | Benin
| `bl` | Saint-Barthélemy
| `bm` | Bermuda
| `bn` | Bruneian
| `bo` | Bolivia
| `bq` | Bonaire
| `br` | Brazil
| `bs` | Bahamas
| `bt` | Bhutan
| `bv` | Bouvet Island
| `bw` | Batswana
| `by` | Belarus
| `bz` | Belize
| `ca` | Canada
| `cc` | Cocos Island
| `cd` | Democratic Republic of Congo
| `cf` | Central African Republic
| `cg` | Republic of the Congo
| `ch` | Switzerland
| `ci` | Ivory Coast
| `ck` | Cook Island
| `cl` | Chile
| `cm` | Cameroon
| `cn` | China
| `co` | Colombia
| `cr` | Costa Rica
| `cu` | Cuba
| `cv` | Cape Verde
| `cw` | Curacao
| `cx` | Christmas Island
| `cy` | Cyprus
| `cz` | Czech Republic
| `de` | Germany
| `dj` | Djibouti
| `dk` | Denmark
| `dm` | Dominica
| `do` | Dominican Republic
| `dz` | Algeria
| `ec` | Ecuador
| `ee` | Estonia
| `eg` | Egypt
| `eh` | Sahrawi
| `er` | Eritrea
| `es` | Spain
| `es-ct` | Catalonia
| `et` | Ethiopia
| `eu` | European Union
| `fi` | Finland
| `fj` | Fiji
| `fk` | Falkland Islands
| `fm` | Federate States of Micronesia
| `fo` | Faroe Islands
| `fr` | France
| `ga` | Gabon
| `gb` | Great Britain
| `gb-eng` | England
| `gb-nir` | Nothern Ireland
| `gb-sct` | Scotland
| `gb-wls` | Wales
| `gd` | Grenada
| `ge` | Georgia
| `gf` | Guyana
| `gg` | Guernsey
| `gh` | Ghana
| `gi` | Gibraltar
| `gl` | Greenland
| `gm` | Gambia
| `gn` | Guinea
| `gp` | Guadeloupe
| `gq` | Equatorial Guinea
| `gr` | Greece
| `gs` | South Georgia
| `gt` | Guatemala
| `gu` | Guam
| `gw` | Guinea-Bissau
| `gy` | Guyana
| `hk` | Hong Kong
| `hm` | Heard and McDonald Islands
| `hn` | Honduras
| `hr` | Croatia
| `ht` | Haiti
| `hu` | Hungary
| `id` | Indonesia
| `ie` | Ireland
| `il` | Israel
| `im` | Isle of Man
| `in` | India
| `io` | British Indian Ocean Territory
| `iq` | Iraq
| `ir` | Iran
| `is` | Iceland
| `it` | Italy
| `je` | Jersey
| `jm` | Jamaica
| `jo` | Jordan
| `jp` | Japan
| `ke` | Kenya
| `kg` | Kyrgyzstan
| `kh` | Cambodia
| `ki` | Kiribati
| `km` | Comoros
| `kn` | Saint Kitts and Nevis
| `kp` | North Korea
| `kr` | South Korea
| `kw` | Kuwait
| `ky` | Cayman Islands
| `kz` | Kazakhstan
| `la` | Laos
| `lb` | Lebanese
| `lc` | Saint Lucia
| `li` | Liechtenstein
| `lk` | Sri Lanka
| `lr` | Liberia
| `ls` | Lesotho
| `lt` | Lithuania
| `lu` | Luxembourg
| `lv` | Latvia
| `ly` | Libya
| `ma` | Morocco
| `mc` | Monaco
| `md` | Moldova
| `me` | Montenegro
| `mf` | Saint Martin
| `mg` | Madagascar
| `mh` | Marshall Islands
| `mk` | Macedonia
| `ml` | Mali
| `mm` | Myanmar
| `mn` | Mongolia
| `mo` | Macao
| `mp` | Nothern Mariana Islands
| `mq` | Martinique
| `mr` | Mauritania
| `ms` | Montserrat
| `mt` | Malta
| `mu` | Mauritius
| `mv` | Maldives
| `mw` | Malawi
| `mx` | Mexico
| `my` | Malaysia
| `mz` | Mozambique
| `na` | Namibia
| `nc` | New Caledonia
| `ne` | Niger
| `nf` | Norfolk Island
| `ng` | Nigeria
| `ni` | Nicaragua
| `no` | Norway
| `np` | Nepal
| `nr` | Nauruan
| `nu` | Niger
| `nz` | New Zeland
| `om` | Oman
| `pa` | Panama
| `pe` | Peru
| `pf` | French Polynesia
| `pg` | Papua New Guinea
| `ph` | Philippines
| `pk` | Pakistan
| `pl` | Poland
| `pm` | Saint Pierre
| `pn` | Pitcairn Islands
| `pr` | Puerto Rico
| `ps` | Palestine
| `pt` | Portugal
| `pw` | Palau
| `py` | Paraguay
| `qa` | Qatar
| `re` | Reunion Island
| `ro` | Romania
| `rs` | Serbia
| `ru` | Russia
| `rw` | Rwanda
| `sa` | Saudi Arabia
| `sb` | Solomon Islands
| `sc` | Seychelles
| `sd` | Sudan
| `se` | Sweden
| `sg` | Singapore
| `sh` | Saint Helena
| `si` | Slovenia
| `sj` | Svalbard Island
| `sk` | Slovakia
| `sl` | Sierra Leone
| `sm` | San Marino
| `sn` | Senegal
| `so` | Somalia
| `sr` | Suriname
| `ss` | South Sudan
| `st` | Sao Tome
| `sv` | El Salvador
| `sx` | Sint Maarten
| `sy` | Syria
| `sz` | Swaziland
| `tc` | Turks and Caicos
| `td` | Chad
| `tf` | French Southern and Antarctic Lands
| `tg` | Togo
| `th` | Thailand
| `tj` | Tajikistan
| `tk` | Tokelau
| `tl` | Timor Leste
| `tm` | Turkmenistan
| `tn` | Tunisia
| `to` | Tonga
| `tr` | Turkey
| `tt` | Trinidad and Tobago
| `tv` | Tuvalu
| `tz` | Tanzania
| `ua` | Ukraine
| `ug` | Uganda
| `um` | United States Minor Islands
| `un` | United Nations
| `us` | United States of America
| `uy` | Uruguay
| `uz` | Uzbekistan
| `va` | Vatican City
| `vc` | Saint Vincent
| `ve` | Venezuela
| `vg` | British Virgin Islands
| `vi` | Virgiin Islands
| `vn` | Vietnam
| `vu` | Vanuatu
| `wf` | Wallis and Futuna
| `ws` | Samoa
| `ye` | Yemen
| `za` | South Africa
| `zm` | Zambia
| `zw` | Zimbabwe